[][src]Crate dogear

Macros

debug
error
trace

Structs

DefaultAbortSignal

A default signal that can't be aborted.

DefaultDriver

A default implementation of the merge driver.

Deletion

Represents an accepted local or remote deletion.

Error
Guid

A GUID for an item in a bookmark tree.

Item

An item in a local or remote bookmark tree.

MergeTimings

Records timings for merging operations.

MergedDescendant

A descendant holds a merged node, merged parent node, position in the merged parent, and level in the merged tree.

MergedNode

A merged bookmark node that indicates which side to prefer, and holds merged child nodes.

MergedRoot

The root of a merged tree, from which all merged nodes descend.

Merger

A two-way merger that produces a complete merged tree from a complete local tree and a complete remote tree with changes since the last sync.

Stats

Records timings and counters for telemetry.

StructureCounts

Records structure change counters for telemetry.

Tree

A complete, rooted bookmark tree with tombstones.

Enums

Content

Content info for an item in the local or remote tree. This is used to dedupe new local items to remote items that don't exist locally, with different GUIDs and similar content.

ErrorKind
Kind

Synced item kinds. Each corresponds to a Sync record type.

MergeState

The merge state indicates which node we should prefer, local or remote, when resolving conflicts.

UploadReason

The reason for uploading or reuploading a merged descendant.

Validity

Synced item validity.

Constants

MENU_GUID

The bookmarks menu GUID.

MOBILE_GUID

The mobile bookmarks GUID.

ROOT_GUID

The Places root GUID, used to root all items in a bookmark tree.

TOOLBAR_GUID

The bookmarks toolbar GUID.

UNFILED_GUID

The "Other Bookmarks" GUID, used to hold items without a parent.

Traits

AbortSignal

An abort signal is used to abort merging. Implementations of AbortSignal can store an aborted flag, usually as an atomic integer or Boolean, set the flag on abort, and have AbortSignal::aborted return the flag's value.

Driver

A merge driver provides methods to customize merging behavior.

Store

A store is the main interface to Dogear. It implements methods for building local and remote trees from a storage backend, fetching content info for matching items with similar contents, and persisting the merged tree.

Type Definitions

Result